@@ -20,7 +20,7 @@
 
 #if defined(WIN32) || defined(_WIN32_WCE)
 #include "ortp-config-win32.h"
-#else
+#elif HAVE_CONFIG_H
 #include "ortp-config.h"
 #endif
 #include "ortp/ortp.h"
@@ -33,6 +33,14 @@ int ortp_allocations=0;
 #endif
 
 
+#ifdef HAVE_SRTP
+#undef PACKAGE_NAME
+#undef PACKAGE_STRING
+#undef PACKAGE_TARNAME
+#undef PACKAGE_VERSION
+#include <srtp/srtp.h>
+#endif
+
 RtpScheduler *__ortp_scheduler;
 
 
@@ -79,6 +87,14 @@ void ortp_init()
 	av_profile_init(&av_profile);
 	ortp_global_stats_reset();
 	init_random_number_generator();
+
+#ifdef HAVE_SRTP
+	if (srtp_init() != err_status_ok) {
+		ortp_fatal("Couldn't initialize SRTP library.");
+	}
+	err_reporting_init("oRTP");
+#endif
+
 	ortp_message("oRTP-" ORTP_VERSION " initialized.");
 }
 
@@ -169,7 +185,7 @@ char * ortp_strdup_vprintf(const char *fmt, va_list ap)
 	/* Guess we need no more than 100 bytes. */
 	int n, size = 200;
 	char *p,*np;
-#ifdef __linux
+#ifndef WIN32
 	va_list cap;/*copy of our argument list: a va_list cannot be re-used (SIGSEGV on linux 64 bits)*/
 #endif
 	if ((p = (char *) ortp_malloc (size)) == NULL)
@@ -177,7 +193,7 @@ char * ortp_strdup_vprintf(const char *fmt, va_list ap)
 	while (1)
 	{
 		/* Try to print in the allocated space. */
-#ifdef __linux
+#ifndef WIN32
 		va_copy(cap,ap);
 		n = vsnprintf (p, size, fmt, cap);
 		va_end(cap);
@@ -256,14 +272,12 @@ static void __ortp_logv_out(OrtpLogLevel lev, const char *fmt, va_list args){
 			ortp_fatal("Bad level !");
 	}
 	msg=ortp_strdup_vprintf(fmt,args);
-#ifdef _MSC_VER
+#if defined(_MSC_VER) && !defined(_WIN32_WCE)
  	OutputDebugString(msg);
   	OutputDebugString("\r\n");
-#else
+#endif
 	fprintf(__log_file,"ortp-%s-%s" ENDLINE,lname,msg);
 	fflush(__log_file);
-#endif
-
 	ortp_free(msg);
 }
 
@@ -302,9 +316,6 @@ void rtp_stats_display(const rtp_stats_t *stats, const char *header)
   ortp_log(ORTP_MESSAGE,
 	   " number of incoming rtp bytes successfully delivered to the application=%lld ",
 	   (long long)stats->recv);
-  ortp_log(ORTP_MESSAGE,
-	   " number of times the application queried a packet that didn't exist=%lld ",
-	   (long long)stats->unavaillable);
   ortp_log(ORTP_MESSAGE,
 	   " number of rtp packet lost=%lld",
 	   (long long) stats->cum_packet_loss);
@@ -336,9 +347,6 @@ void rtp_stats_display(const rtp_stats_t *stats, const char *header)
   ortp_log(ORTP_MESSAGE,
 	   " number of incoming rtp bytes successfully delivered to the application=%I64d ",
 	   (uint64_t)stats->recv);
-  ortp_log(ORTP_MESSAGE,
-	   " number of times the application queried a packet that didn't exist=%I64d ",
-	   (uint64_t)stats->unavaillable);
   ortp_log(ORTP_MESSAGE,
 	   " number of rtp packet lost=%I64d",
 	   (uint64_t) stats->cum_packet_loss);
